from fileioutilities.file_io import FileIO
from bdaserviceutils import get_args


class GenericService():
    def __init__(self):
        super().__init__()
        self._args = get_args()

    def download_model(self, path):
        fileIO = FileIO(storage_type=self._args['dataStorageType-input-model'])
        fileIO.download(remote_path=get_args()['input-model'], local_path=path)

    def upload_model(self, path):
        fileIO = FileIO()
        fileIO.upload(local_path=path, remote_path=self._args['output-model'])



from .spark_service import SparkService


class PandasService(SparkService):
    def __init__(self):
        super().__init__()

    def get_dataset(self):
        return super().get_dataset().toPandas()

    def save_dataset(self, dataset):
        super().save_dataset(self.spark.createDataFrame(dataset))



import setuptools

setuptools.setup(
    name="bda-service-template",
    version="0.0.2.3",
    author="Alida research team",
    author_email="salvatore.cipolla@eng.it",
    description="Bda templates to build python services for Alida",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires = [
        "file-io-utilities>=0.0.1.22",
        "pyspark-utilities>=0.0.14",
        "bda-service-utils>=0.0.1.28"
        ],
)
